﻿using AutoMapper;
using BizService;
using Model.Dto;
using Model.Entities;
using PLCTool.Common;
using Prism.Commands;
using Prism.Mvvm;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace PLCTool.ViewModels.MonitorManageViewModel
{
    public  class PLCWriteViewModel:BindableBase
    {
        private readonly IBasicPlcItemConfigService _iBasPlcItemConfigService;

        private readonly IMapper _mapper;
        private List<BasPlcItemConfigDto> plcConfigs = new List<BasPlcItemConfigDto>();
        public PLCWriteViewModel(IBasicPlcItemConfigService iBasPlcItemConfigService, IMapper mapper)
        {

            _iBasPlcItemConfigService = iBasPlcItemConfigService;
            _mapper = mapper;
            WriteCommand = new DelegateCommand<object>(WriteToPlc);
            GetPLCConfig();
        }


        #region 私有方法

        private void WriteToPlc(object obj)
        {
            foreach (var item in PLCItemList)
            {
                //没有连接 plc，直接退出
                if (!PLCCom.GetInstance().IsConnectPLC())
                {
                    break;
                }
                string plcAddr = item.PlcAddress;
                string plcAddType = item.PlcAddType;
                switch (plcAddType)
                {
                    case "bool":
                        bool isResult=PLCCom.GetInstance().WritePlcObject(plcAddr, VarType.Bit, WritePLCValue);
                        break;
                    case "word":
                        bool isResult2 = PLCCom.GetInstance().WritePlcObject(plcAddr, VarType.Word, WritePLCValue);
                        break;
                    case "dword":
                        bool isResult3 = PLCCom.GetInstance().WritePlcObject(plcAddr, VarType.DWord, WritePLCValue);
                        break;
                    case "real":
                        bool isResult4 = PLCCom.GetInstance().WritePlcObject(plcAddr, VarType.Real, WritePLCValue);
                        break;
                }

            }
        }
        /// <summary>
        /// 获取PLC配置
        /// </summary>
        private void GetPLCConfig()
        {
            var plclist = _iBasPlcItemConfigService.QueryList();
            plcConfigs = _mapper.Map<List<bas_plc_item_config>, List<BasPlcItemConfigDto>>(plclist);
            foreach (var plc in plcConfigs)
            {
                PLCItemList.Add(plc);
            }
        }

    
        #endregion
        #region 数据绑定
        private ObservableCollection<BasPlcItemConfigDto> plcItemList = new ObservableCollection<BasPlcItemConfigDto>();
        public ObservableCollection<BasPlcItemConfigDto> PLCItemList
        {
            get { return plcItemList; }
            set { plcItemList = value; RaisePropertyChanged(); }
        }

        /// <summary>
        /// 写入值
        /// </summary>
        private string writePLCValue;
        public string WritePLCValue
        {
            get { return writePLCValue; }
            set { writePLCValue = value; RaisePropertyChanged(); }
        }
        #endregion

        #region 命令绑定

        public DelegateCommand<object> WriteCommand { set; get; }
        #endregion
    }
}

